#
# spec file for package libcxgb4-rdmav2
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           libcxgb4-rdmav2
Summary:        Chelsio T4 iWARP RNIC OpenIB Userspace Library
Version:        1.3.5
Release:        4.3
License:        GPL-2.0 or BSD-2-Clause
Group:          System/Libraries
Source0:        https://www.openfabrics.org/downloads/cxgb4/libcxgb4-%{version}.tar.gz
#Git-Clone:	git://www.openfabrics.org/~swise/libcxgb4
Patch1:		libcxgb4-fix_puns.patch
Patch2:         libcxgb4-rdmav2-ah_message.patch
Url:            http://www.openfabrics.org
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  libibverbs-devel
BuildRequires:  automake autoconf libtool

%description
libcxgb4 provides a device-specific userspace driver for Chelsio T4 iWARP 
RNICs for use with the libibverbs library.

%prep
%setup -q -n libcxgb4-%{version}
%patch1
%patch2

touch NEWS ChangeLog

%build
autoreconf -fi
%configure --disable-static --disable-silent-rules
make %{?_smp_mflags}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%install
%makeinstall
rm -f %{buildroot}%{_libdir}/{*.la,libcxgb4.so}

%files
%defattr(-, root, root)
%doc ChangeLog COPYING
%dir %_sysconfdir/libibverbs.d
%config %_sysconfdir/libibverbs.d/*
%_libdir/libcxgb4-rdmav2.so

%changelog
* Wed Feb  4 2015 p.drouand@gmail.com
- Update to version 1.3.5
  * libcxb4: use wc_wmb() instead of wmb().
    The user mode RDMA macro for wmb() is not sufficient to provide the
    fencing needed.  This was causing corrupted packets when running multiple
    WD-UDP sockperf processes.  The correct "sfence" instruction is provided
    with the wc_wmb() macro.  See /usr/include/infiniband/arch.h.
    Note:  The kernel implementation of wmb() is sufficient.  This is a
    libcxgb4 issue only...
- Use download Url as source
- Update libcxgb4-rdmav2-ah_message.patch
* Tue Jul  8 2014 pth@suse.de
- Add ChangeLog and COPYING to documentation.
* Tue Jun  3 2014 pth@suse.de
- Update to OFED 3.12 final.
* Wed May 14 2014 pth@suse.de
- Use tarball from OFED 3.12 RC2
* Thu Apr  3 2014 pth@suse.de
- Update to 1.3.3: (bnc#863631)
  * Zero the status_page_size before calling get_context.
* Wed Feb 26 2014 pth@suse.de
- Update to 1.3.2 from the latest daily OFED 3.12:
  * Use V_PIDX_T5() for T5 devices in ring_db funcs.
  * Call wc_wmb() needed after DB writes.
    Need to do an sfence after both the WC and regular PIDX DB write.
    Otherwise the host might reorder things and cause work request corruption
    (seen with NFSRDMA).
  * Call rmb() after reading valid gen bit.
    Some HW platforms can reorder read operations, so we must rmb() after
    we see a valid gen bit in a CQE but before we read any other fields
    from the CQE.
  * Refresh t4 fw/hw reg files.
  * Add common device id table and chip types.
    This will make it easier to merge in new devices.
  * iw_cxgb4/libcxgb4: swsq "signaled" state needs to mind sq_sig_all.
    When a qp is created, the ULP can request that all sq wrs be signaled.
    The swsqe entries need to take this into account when marking the entry
    as signaled.
    This bug will cause read request CQEs to be silently discarded, and can
    cause flush problems because the swsqe entry will be mismarked for qps
    created with sq_sig_all set in the qp init attributes.
  * never consume a pending wr in sq flush.
    There is a race when moving a QP from RTS->CLOSING where a SQ work
    request could be posted after the FW receives the RDMA_RI/FINI WR.
    The SQ work request will never get processed, and should be completed
    with FLUSHED status.  Function c4iw_flush_sq(), however was dropping
    the oldest SQ work request when in CLOSING or IDLE states, instead of
    completing the pending work request. If that oldest pending work request
    was actually complete and has a CQE in the CQ, then when that CQE is
    proceessed in poll_cq, we'll BUG_ON() due to the inconsistent SQ/CQ state.
    This is a very small timing hole and has only been hit once so far.
    c4iw_flush_sq() MUST always flush all non-completed WRs with FLUSHED
    status regardless of the QP state.
  * unmap status page when freeing the context.
  * DB Drop Avoidance, Version 2.
    Add support for the device status page mapped per device that is used
    to enable/disable user db usage.
  * Fix DEBUG code in c4iw_flush_hw_cq().
  * T4 onchip workaround: do the 16 4B MA writes just before DB ring.
- Adapt the patches to the source changes
* Fri Jan 31 2014 pth@suse.de
- This is a plugin, no devel package needed.
* Wed Jan 29 2014 pth@suse.de
- Adapt patches to changed sources:
  * libcxgb4-fix_puns.patch
- Adapt and apply libcxgb4-rdmav2-ah_message.patch.
* Fri Jan 24 2014 pth@suse.de
- Remove old tarball.
* Fri Jan 17 2014 pth@suse.de
- Update to OFED 3.12 daily
- Enable build for s390x.
- Use spdx.org format for license specification.
* Fri Sep  7 2012 pth@suse.de
- Rename fix_puns.diff to libcxgb4-rdmav2-fix_puns.patch.
- Use AS_HELP_STRING to format help messages.
* Wed Sep  5 2012 jengelh@inai.de
- Update to new upstream release 1.2.0
  * No high-level changelog provided by upstream
- Remove redundant sections from specfile
- Parallel build with %%_smp_mflags
- Do own the config directory
* Tue May  8 2012 pth@suse.de
- BuildRequire automake, autoconf and libtool.
* Mon Aug 15 2011 pth@suse.de
- Change license to GPL-2.0 or BSD2c as detailed in bnc#712220 .
* Fri Aug 12 2011 pth@suse.de
- Initial package (bnc#711400).
